# Luncher
Aplikace pro profesionální management obědů.

Aplikace sestává ze tří (čtyř) modulů.
- food_api
  - Python scraper/parser pro zpracování obědových menu restaurací
- server
  - backend psaný v [node.js](https://nodejs.dev)
- client
  - frontend psaný v [React.js](https://react.dev)
- [nginx](https://nginx.org)
  - proxy pro snadné propojení Docker kontejnerů pod jednou URL

## Spuštění pro vývoj
### Závislosti
#### Food API
- [Python 3](https://www.python.org)
- [pip](https://pypi.org/project/pip)
#### Klient/server
- [Node.js 18.x](https://nodejs.dev)
- [Yarn 1.22.x (Classic)](https://classic.yarnpkg.com)

### Spuštění na *nix platformách
- Nainstalovat závislosti viz předchozí bod
- Zkopírovat `client/.env.template` do `client/.env.development` a upravit dle potřeby
- Zkopírovat `server/.env.template` do `server/.env.development` a upravit dle potřeby
- Spustit `./run_dev.sh`. Na jiných platformách se lze inspirovat jeho obsahem, postup by měl být víceméně stejný.

## Sestavení a spuštění produkční verze v Docker
### Závislosti
- [Docker](https://www.docker.com)
- [Docker Compose](https://docs.docker.com/compose)

### Spuštění
- `docker compose up --build -d`

## TODO
- [x] Umožnit smazání aktuální volby "popelnicí", místo nutnosti vybrat prázdnou položku v selectu
- [x] Přívětivější možnost odhlašování
- [x] Vyřešit responzivní design pro použití na mobilu
- [x] Vyndat URL na Food API do .env
- [x] Neselhat při nedostupnosti nebo chybě z Food API
- [x] Dokončit docker-compose pro kompletní funkčnost
- [x] Implementovat Pizza day
  - [x] Umožnit uzamčení objednávek zakladatelem
  - [x] Možnost uložení čísla účtu
  - [ ] Automatické generování a zobrazení QR kódů
    - [ ] https://qr-platba.cz/pro-vyvojare/restful-api/
  - [ ] Zobrazovat celkovou cenu objednávky pod tabulkou objednávek
  - [ ] Zobrazit upozornění před smazáním/zamknutím/odemknutím pizza day
  - [ ] Umožnit přidat k objednávce poznámku (např. "bez oliv")
- [ ] Předvyplnění poslední vybrané hodnoty občas nefunguje, viz komentář
- [ ] Nasazení nové verze v Docker smaže veškerá data (protože data.json není venku)
- [ ] Vylepšit dokumentaci projektu
  - [ ] Popsat Food API, nginx
  - [x] Popsat závislosti, co je nutné provést před vývojem a postup spuštění pro vývoj
  - [x] Popsat dostupné env
- [ ] Pizzy se samy budou při naklikání přidávat do košíku
  - [ ] Nutno nejprve vyřešit předávání PHPSESSIONID cookie na pizzachefie.cz pomocí fetch()
- [ ] Přesunout autentizaci na server (JWT?)
- [x] Zavést .env.template a přidat .env do .gitignore
- [ ] Zkrášlit dialog pro vyplnění čísla účtu, vypadá mizerně
- [ ] Podpora pro notifikace v externích systémech (Gotify, Discord, MS Teams)
- [ ] Skripty pro snadné spuštění vývoje na Windows (ekvivalent ./run_dev.sh)
- [ ] Možnost náhledu na jiné dny v týdnu (např. pomocí šipek)
  - [ ] Možnost zadat si oběd dopředu na následující dny v týdnu