import React, { useRef, useState } from "react";
import { Navbar, Nav, NavDropdown, Modal, Button } from "react-bootstrap";
import { useAuth } from "../context/auth";
import { useBank } from "../context/bank";


export default function Header() {
    const auth = useAuth();
    const bank = useBank();
    const [modalOpen, setModalOpen] = useState<boolean>(false);
    const bankAccountRef = useRef<HTMLInputElement>(null);
    const nameRef = useRef<HTMLInputElement>(null);

    const openBankSettings = () => {
        setModalOpen(true);
    }

    const closeModal = () => {
        setModalOpen(false);
    }

    const save = () => {
        // TODO validace na modulo 11
        bank?.setBankAccountNumber(bankAccountRef.current?.value);
        bank?.setBankAccountHolderName(nameRef.current?.value);
        closeModal();
    }

    return <Navbar variant='dark' expand="lg">
        <Navbar.Brand>Luncher</Navbar.Brand>
        <Navbar.Toggle aria-controls="basic-navbar-nav" />
        <Navbar.Collapse id="basic-navbar-nav">
            <Nav className="nav">
                <NavDropdown align="end" title={auth?.login} id="basic-nav-dropdown">
                    <NavDropdown.Item onClick={openBankSettings}>Nastavit číslo účtu</NavDropdown.Item>
                    <NavDropdown.Item onClick={auth?.clearLogin}>Odhlásit se</NavDropdown.Item>
                </NavDropdown>
            </Nav>
        </Navbar.Collapse>
        <Modal show={modalOpen} onHide={closeModal}>
            <Modal.Header closeButton>
                <Modal.Title>Bankovní účet</Modal.Title>
            </Modal.Header>
            <Modal.Body>
                <p>Nastavením čísla účtu umožníte automatické generování QR kódů pro úhradu za vámi provedené objednávky v rámci Pizza day.<br />Pokud vaše číslo účtu neobsahuje předčíslí, je možné ho zcela vynechat.<br /><br />Poznámka: Číslo účtu není aktuálně nijak validováno. Ověřte si jeho správnost.</p>
                Číslo účtu: <input ref={bankAccountRef} type="text" placeholder="123456-1234567890/1234" /> <br />
                Název příjemce (nepovinné): <input ref={nameRef} type="text" placeholder="Jan Novák" />
            </Modal.Body>
            <Modal.Footer>
                <Button variant="secondary" onClick={closeModal}>
                    Storno
                </Button>
                <Button variant="primary" onClick={save}>
                    Uložit
                </Button>
            </Modal.Footer>
        </Modal>
    </Navbar>
}